@@ -3,7 +3,10 @@
 
 #include <unistd.h>
 
-extern void parse_command(char *, char ***, int *);
+extern void
+parse_command(char*, char***, int*);
+
+extern pid_t
+execCommand(char*);
 
-extern pid_t execCommand(char *);
 #endif				/* __MISC_H */
